@@ -90,18 +90,18 @@ DeclarativeAdapter *DeclarativeManager::usableAdapter() const
 
 QQmlListProperty<DeclarativeAdapter> DeclarativeManager::declarativeAdapters()
 {
-    return QQmlListProperty<DeclarativeAdapter>(this, 0, adaptersCountFunction, adaptersAtFunction);
+    return QQmlListProperty<DeclarativeAdapter>(this, nullptr, adaptersCountFunction, adaptersAtFunction);
 }
 
 QQmlListProperty<DeclarativeDevice> DeclarativeManager::declarativeDevices()
 {
-    return QQmlListProperty<DeclarativeDevice>(this, 0, devicesCountFunction, devicesAtFunction);
+    return QQmlListProperty<DeclarativeDevice>(this, nullptr, devicesCountFunction, devicesAtFunction);
 }
 
 DeclarativeAdapter *DeclarativeManager::declarativeAdapterFromPtr(BluezQt::AdapterPtr ptr) const
 {
     if (!ptr) {
-        return Q_NULLPTR;
+        return nullptr;
     }
     return m_adapters.value(ptr->ubi());
 }
@@ -109,7 +109,7 @@ DeclarativeAdapter *DeclarativeManager::declarativeAdapterFromPtr(BluezQt::Adapt
 DeclarativeDevice *DeclarativeManager::declarativeDeviceFromPtr(BluezQt::DevicePtr ptr) const
 {
     if (!ptr) {
-        return Q_NULLPTR;
+        return nullptr;
     }
     return m_devices.value(ptr->ubi());
 }
